@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.15'
+__version__ = '0.1.16'
 
 __all__ = [
     'NEVER',
@@ -44,6 +44,7 @@ from types import ModuleType
 from fluentmock.exceptions import (CouldNotVerifyCallError,
                                    HasBeenCalledAtLeastOnceError,
                                    InvalidAttributeError,
+                                   InvalidUsageOfAnyArgumentsError,
                                    NoCallsStoredError,
                                    HasBeenCalledWithDifferentArgumentsError)
 
@@ -219,6 +220,9 @@ class FluentMockConfigurator(object):
         self._fluent_mock = fluent_mock
 
     def __call__(self, *arguments, **keyword_arguments):
+        if len(arguments) > 1 and ANY_ARGUMENTS in arguments:
+            raise InvalidUsageOfAnyArgumentsError()
+
         answer = FluentAnswer(arguments, keyword_arguments)
         self._fluent_mock.append_new_answer(answer)
         return answer
@@ -300,7 +304,9 @@ class Verifier(FluentTarget):
         found_calls = self._find_calls_to_same_target()
 
         if found_calls:
-            if arguments and arguments[0] is ANY_ARGUMENTS:
+            if arguments and ANY_ARGUMENTS in arguments:
+                if len(arguments) > 1:
+                    raise InvalidUsageOfAnyArgumentsError()
                 return
             raise HasBeenCalledWithDifferentArgumentsError(expected_call_entry, found_calls)
 
